Build Failure (Was Re: 2.6.23-mm1)

2007-10-12 Thread Dhaval Giani
On Thu, Oct 11, 2007 at 09:31:26PM -0700, Andrew Morton wrote:
 
 ftp://ftp.kernel.org/pub/linux/kernel/people/akpm/patches/2.6/2.6.23/2.6.23-mm1/
 

Hi Andrew

My compile just failed with 

drivers/scsi/gdth.c: In function ‘gdth_search_dev’:
drivers/scsi/gdth.c:646: warning: ‘pci_find_device’ is deprecated
(declared at include/linux/pci.h:482)
drivers/scsi/gdth.c: In function ‘gdth_init_isa’:
drivers/scsi/gdth.c:857: error: ‘gdth_irq_tab’ undeclared (first use in
this function)
drivers/scsi/gdth.c:857: error: (Each undeclared identifier is reported
only once
drivers/scsi/gdth.c:857: error: for each function it appears in.)
drivers/scsi/gdth.c: In function ‘gdth_copy_internal_data’:
drivers/scsi/gdth.c:2362: warning: unused variable ‘sg’
make[2]: *** [drivers/scsi/gdth.o] Error 1
make[1]: *** [drivers/scsi] Error 2
make: *** [drivers] Error 2
[EMAIL PROTECTED] linux-2.6.23]$

Looking into the code I notice that gdth_irq_tab is not declared with
CONFIG_ISA=y and !CONFIG_EISA.

The values seem to be same in 2.6.23 (I am not sure why it has been put
with #ifdefs in -mm) so I have just modified the #ifdef to take care of
CONFIG_ISA as well.

(Compile tested only)

Thanks,

--

Signed-off-by: Dhaval Giani [EMAIL PROTECTED]


Index: linux-2.6.23/drivers/scsi/gdth.c
===
--- linux-2.6.23.orig/drivers/scsi/gdth.c   2007-10-12 14:07:28.0 
+0530
+++ linux-2.6.23/drivers/scsi/gdth.c2007-10-12 15:06:47.0 +0530
@@ -288,7 +288,7 @@ static struct timer_list gdth_timer;
 #ifdef CONFIG_ISA
 static unchar   gdth_drq_tab[4] = {5,6,7,7};/* DRQ table */
 #endif
-#ifdef CONFIG_EISA
+#if defined(CONFIG_EISA) || defined(CONFIG_ISA)
 static unchar   gdth_irq_tab[6] = {0,10,11,12,14,0};/* IRQ table */
 #endif
 static unchar   gdth_polling;   /* polling if TRUE */

-- 
regards,
Dhaval
-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 0/3] Update sysfs registration

2007-10-12 Thread James Bottomley
On Fri, 2007-10-12 at 16:42 +0200, Hannes Reinecke wrote:
 Hi James,
 
 I recently posted this patchset:
 
  these patches are a follow-up to the earlier patch from Kay Sievers named
  [SCSI] switch sdev sysfs attributes to default attributes.
  It consists of three parts:
  
  - PATCH 1/3: Rework scsi target allocation so that uevents will only
be sent for existing targets
  - PATCH 2/3: Add scsi_bus type to scsi_target and scsi_host, so they
will show up in the scsi bus device listing.
  - PATCH 3/3: switch scsi_host sysfs attributes to default attributes
  
 Did you have a chance to look at it?
 Will that be included in 2.6.24?
 
 Some other pending sysfs patches are based on this, so we'd rather like to
 know where we stand ...

They're on the list of things needing careful review.  I'll hopefully
have some time in the next week to look through them.

James


-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 0/3] Update sysfs registration

2007-10-12 Thread Hannes Reinecke
Hi James,

I recently posted this patchset:

 these patches are a follow-up to the earlier patch from Kay Sievers named
 [SCSI] switch sdev sysfs attributes to default attributes.
 It consists of three parts:
 
 - PATCH 1/3: Rework scsi target allocation so that uevents will only
   be sent for existing targets
 - PATCH 2/3: Add scsi_bus type to scsi_target and scsi_host, so they
   will show up in the scsi bus device listing.
 - PATCH 3/3: switch scsi_host sysfs attributes to default attributes
 
Did you have a chance to look at it?
Will that be included in 2.6.24?

Some other pending sysfs patches are based on this, so we'd rather like to
know where we stand ...

Cheers,

Hannes
-- 
Dr. Hannes Reinecke   zSeries  Storage
[EMAIL PROTECTED] +49 911 74053 688
SUSE LINUX Products GmbH, Maxfeldstr. 5, 90409 Nürnberg
GF: Markus Rex, HRB 16746 (AG Nürnberg)
-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: drivers/fc4/fc.c in git-scsi-misc

2007-10-12 Thread James Bottomley
On Thu, 2007-10-11 at 17:38 -0700, David Miller wrote:
 From: Andrew Morton [EMAIL PROTECTED]
 Date: Thu, 11 Oct 2007 11:20:58 -0700
 
  Well if fc4.c compiles OK on non-sparc64 then perhaps we should enable
  compilation on non-sparc64.  It will increase maintainability and code
  quality and stuff.
 
 No objections to including drivers/fc4/Kconfig directly from
 drivers/Kconfig.
 
 It's only included directly from arch/sparc64/Kconfig because
 long long ago drivers/Kconfig could not be safely included
 there.

Would you be able to test out Matthew's patch and ack it?  Not having
fc4 compile is a blocker for the necessary SCSI merge.

James


-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [patch 1/1] scsi: expose AN support to user space

2007-10-12 Thread Jeff Garzik

[EMAIL PROTECTED] wrote:

From: Kristen Carlson Accardi [EMAIL PROTECTED]

If a scsi_device supports async notification for media change, then let user
space know this capability exists by creating a new sysfs entry
media_change_notify, which will be 1 if it is supported, and 0 if not
supported.  Create a routine which allows scsi devices to send a uevent when
media change events occur.

Signed-off-by: Kristen Carlson Accardi [EMAIL PROTECTED]
Acked-by: Jeff Garzik [EMAIL PROTECTED]
Cc: Tejun Heo [EMAIL PROTECTED]
Cc: James Bottomley [EMAIL PROTECTED]
Signed-off-by: Andrew Morton [EMAIL PROTECTED]


Ping?


-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH 3/3] faster workaround

2007-10-12 Thread Jeff Garzik

Bernd Schubert wrote:
a) 2.6.23 + sil-patch I posted, this is on a customer system (though my former 
group), I wouldn't like to use -mm there.


b) .config is attached

c) attached

d) attached (don't get irritaded by those machine check events, thats GART 
TLB errorr, harmless warnings, just not disabled in the bios).


Any chance you could provide dmesg on 2.6.23 without the sil patch?

Jeff



-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: drivers/fc4/fc.c in git-scsi-misc

2007-10-12 Thread David Miller
From: James Bottomley [EMAIL PROTECTED]
Date: Fri, 12 Oct 2007 13:04:33 -0500

 On Thu, 2007-10-11 at 17:38 -0700, David Miller wrote:
  From: Andrew Morton [EMAIL PROTECTED]
  Date: Thu, 11 Oct 2007 11:20:58 -0700
  
   Well if fc4.c compiles OK on non-sparc64 then perhaps we should enable
   compilation on non-sparc64.  It will increase maintainability and code
   quality and stuff.
  
  No objections to including drivers/fc4/Kconfig directly from
  drivers/Kconfig.
  
  It's only included directly from arch/sparc64/Kconfig because
  long long ago drivers/Kconfig could not be safely included
  there.
 
 Would you be able to test out Matthew's patch and ack it?  Not having
 fc4 compile is a blocker for the necessary SCSI merge.

Unfortunately it doesn't build.  The drivers/scsi/pluto.c part
fails with:

drivers/scsi/pluto.c: In function $,1rx(Bpluto_detect$,1ry(B:
drivers/scsi/pluto.c:159: error: $,1rx(Bpluto_detect_done$,1ry(B undeclared 
(first use in this function)
drivers/scsi/pluto.c:159: error: (Each undeclared identifier is reported only 
once
drivers/scsi/pluto.c:159: error: for each function it appears in.)
make[1]: *** [drivers/scsi/pluto.o] Error 1
make: *** [drivers/scsi/pluto.o] Error 2

I think it can be fixed by merely removing the assignment on that
line, but I'l like Matthew to look at that and generate a new
patch if he agrees that is sufficient.

Also, drivers/fc4/fc.c gives a warning:

drivers/fc4/fc.c: In function $,1rx(Bfcp_scsi_abort$,1ry(B:
drivers/fc4/fc.c:867: warning: unused variable $,1rx(Bfcmd$,1ry(B
drivers/fc4/fc.c: In function $,1rx(B__fcp_scsi_host_reset$,1ry(B:
drivers/fc4/fc.c:990: warning: unused variable $,1rx(Bfcmd$,1ry(B

which is fixed thusly:

--- ./drivers/fc4/fc.c~ 2007-10-12 15:21:20.0 -0700
+++ ./drivers/fc4/fc.c  2007-10-12 15:22:03.0 -0700
@@ -864,7 +864,6 @@
 int fcp_scsi_abort(struct scsi_cmnd *SCpnt)
 {
/* Internal bookkeeping only. Lose 1 cmd_slots slot. */
-   fcp_cmnd *fcmd = FCP_CMND(SCpnt);
fc_channel *fc = FC_SCMND(SCpnt);

/*
@@ -987,7 +986,6 @@
 static int __fcp_scsi_host_reset(struct scsi_cmnd *SCpnt)
 {
fc_channel *fc = FC_SCMND(SCpnt);
-   fcp_cmnd *fcmd = FCP_CMND(SCpnt);
int i;
 
printk (FC: host reset\n);
-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [git patches] libata update

2007-10-12 Thread Luben Tuikov
You should run git-update-server-info in 
pub/scm/linux/kernel/git/jgarzik/libata-dev.git.

info/refs disagrees with refs/heads/* .

   Luben

--- Jeff Garzik [EMAIL PROTECTED] wrote:

 
 [ I just sent this upstream to Andrew and Linus ]
 
 Now that I have nailed down the corruption problem, I can attend to
 this...  Fun stuff:
 
 * port multiplier support (like an ethernet hub, only dumber)
 
 * Asynchronous notification -- finally userspace CD-ROM polling can go away!
   (NOTE: waiting on James B to apply the piece that actually makes this
   work...)
 
 * Alan continues to hammer out edge cases in generic ATA support.  An
   amazing amount of ancient and/or obscure hardware works with libata   
 thanks to him :)
 
 * Turn on ACPI by default (watch for bug reports!).  This should make
   suspend/resume work a lot better.
 
 * New drivers for embedded ATA chips.
 
 
 Please pull from 'upstream-linus' branch of
 master.kernel.org:/pub/scm/linux/kernel/git/jgarzik/libata-dev.git 
 upstream-linus
 
 to receive the following updates:
 
  Documentation/kernel-parameters.txt  |8 +-
  drivers/ata/Kconfig  |   59 ++-
  drivers/ata/Makefile |8 +-
  drivers/ata/ahci.c   |  451 +++---
  drivers/ata/ata_generic.c|   16 +-
  drivers/ata/ata_piix.c   |   71 +-
  drivers/ata/libata-acpi.c|  165 +++-
  drivers/ata/libata-core.c| 1329 ++--
  drivers/ata/libata-eh.c  |  922 ++--
  drivers/ata/libata-pmp.c | 1191 +
  drivers/ata/libata-scsi.c|  496 +++
  drivers/ata/libata-sff.c |   69 +-
  drivers/ata/libata.h |   41 +-
  drivers/ata/pata_acpi.c  |  395 
  drivers/ata/pata_ali.c   |   17 +-
  drivers/ata/pata_amd.c   |   43 +-
  drivers/ata/pata_artop.c |   20 +-
  drivers/ata/pata_at32.c  |  441 +
  drivers/ata/pata_atiixp.c|   15 +-
  drivers/ata/pata_bf54x.c | 1627 
 ++
  drivers/ata/pata_cmd640.c|4 +-
  drivers/ata/pata_cmd64x.c|   43 +-
  drivers/ata/pata_cs5520.c|   47 +-
  drivers/ata/pata_cs5530.c|4 +-
  drivers/ata/pata_cs5535.c|4 +-
  drivers/ata/pata_cypress.c   |4 +-
  drivers/ata/pata_efar.c  |   11 +-
  drivers/ata/pata_hpt366.c|4 +-
  drivers/ata/pata_hpt37x.c|   28 +-
  drivers/ata/pata_hpt3x2n.c   |   11 +-
  drivers/ata/pata_hpt3x3.c|   10 +-
  drivers/ata/pata_icside.c|   39 +-
  drivers/ata/pata_isapnp.c|8 +-
  drivers/ata/pata_it8213.c|   11 +-
  drivers/ata/pata_it821x.c|   17 +-
  drivers/ata/pata_ixp4xx_cf.c |   24 +-
  drivers/ata/pata_jmicron.c   |   24 +-
  drivers/ata/pata_legacy.c|   27 +-
  drivers/ata/pata_marvell.c   |   12 +-
  drivers/ata/pata_mpc52xx.c   |9 +-
  drivers/ata/pata_mpiix.c |   25 +-
  drivers/ata/pata_netcell.c   |5 +-
  drivers/ata/pata_ns87410.c   |   11 +-
  drivers/ata/pata_ns87415.c   |  467 ++
  drivers/ata/pata_oldpiix.c   |   11 +-
  drivers/ata/pata_opti.c  |   11 +-
  drivers/ata/pata_optidma.c   |   26 +-
  drivers/ata/pata_pcmcia.c|   16 +-
  drivers/ata/pata_pdc2027x.c  |  114 ++--
  drivers/ata/pata_pdc202xx_old.c  |   23 +-
  drivers/ata/pata_platform.c  |   16 +-
  drivers/ata/pata_qdi.c   |   15 +-
  drivers/ata/pata_radisys.c   |4 +-
  drivers/ata/pata_rz1000.c|   13 +-
  drivers/ata/pata_sc1200.c|4 +-
  drivers/ata/pata_scc.c   |   66 +-
  drivers/ata/pata_serverworks.c   |8 +-
  drivers/ata/pata_sil680.c|   11 +-
  drivers/ata/pata_sis.c   |   33 +-
  drivers/ata/pata_sl82c105.c  |   11 +-
  drivers/ata/pata_triflex.c   |   11 +-
  drivers/ata/pata_via.c   |   16 +-
  drivers/ata/pata_winbond.c   |   13 +-
  drivers/ata/pdc_adma.c   |  103 ++-
  drivers/ata/sata_inic162x.c  |   34 +-
  drivers/ata/sata_mv.c|   68 +-
  drivers/ata/sata_nv.c|   53 +-
  drivers/ata/sata_promise.c   |   27 +-
  drivers/ata/sata_qstor.c |   17 +-
  drivers/ata/sata_sil.c   |   53 +-
  drivers/ata/sata_sil24.c |  341 ++--
  drivers/ata/sata_sis.c   |2 -
  drivers/ata/sata_svw.c   |   14 +-
  drivers/ata/sata_sx4.c   |   25 +-
  drivers/ata/sata_uli.c   |   16 +-
  drivers/ata/sata_via.c   |   35 +-
  drivers/ata/sata_vsc.c   |   16 +-
  drivers/scsi/ipr.c   

Re: [git patches] libata update

2007-10-12 Thread Bartlomiej Zolnierkiewicz

On Friday 12 October 2007, Jeff Garzik wrote:
 
 [ I just sent this upstream to Andrew and Linus ]
 
 Now that I have nailed down the corruption problem, I can attend to
 this...  Fun stuff:
 
 * port multiplier support (like an ethernet hub, only dumber)

Great to see this here.

 * Asynchronous notification -- finally userspace CD-ROM polling can go away!

Is this AHCI specific or could be used by some other SATA hosts?

   (NOTE: waiting on James B to apply the piece that actually makes this
   work...)
 
 * Alan continues to hammer out edge cases in generic ATA support.  An
   amazing amount of ancient and/or obscure hardware works with libata   
 thanks to him :)

Worth to mention that this update also contains two new drivers from Alan,
pata_acpi and pata_ns87415. :)

 * Turn on ACPI by default (watch for bug reports!).  This should make
   suspend/resume work a lot better.
 
 * New drivers for embedded ATA chips.

Unfortunately both are broken ATM, details below.

[ added Sonic Zhang and Kristoffer Nyborg Gregertsen to cc: ]

 Please pull from 'upstream-linus' branch of
 master.kernel.org:/pub/scm/linux/kernel/git/jgarzik/libata-dev.git 
 upstream-linus

[ ... ]

 Alan Cox (22):
   pata_cmd64x: Set up MWDMA modes properly

two minor things:

a.

@@ -88,14 +88,15 @@ static int cmd648_cable_detect(struct ata_port *ap)
 }
 
 /**
  * cmd64x_set_piomode  -   set initial PIO mode data
  * @ap: ATA interface
  * @adev: ATA device
+ * @mode: mode
  *
  * Called to do the PIO mode setup.
  */
 
-static void cmd64x_set_piomode(struct ata_port *ap, struct ata_device *adev)
+static void cmd64x_set_timing(struct ata_port *ap, struct ata_device *adev, u8 
mode)
 {
struct pci_dev *pdev = to_pci_dev(ap-host-dev);
struct ata_timing t;

function name in the documentation needs fixing

b.

regD fiddling in cmd64x_set_dmamode() could be removed completly

   libata: correct handling of SRST reset sequences

This potentially adds a regression for nVidia boxes (but ACPI cable
detection should compensate for it):

pata_amd's -cable_detect checks UDMA timings to get the cable type
(cable detection is done before the SRST) but pata_amd's -set_piomode
messes with UDMA timings.  It seems that both methods need fixing.

 Jeff Garzik (14):

   [libata] Turn on ACPI by default

-MODULE_PARM_DESC(noacpi, Disables the use of ACPI in suspend/resume when 
set);
+MODULE_PARM_DESC(noacpi, Disables the use of ACPI in probe/suspend/resume 
when set);

Would be nice to have Documentation/kernel-parameters.txt updated as well.

 Kristoffer Nyborg Gregertsen (1):
   AVR32 PATA driver

Won't build because this libata update removes -irq_ack and -port_disable
methods from struct ata_port.

 Sonic Zhang (1):
   libata driver for bf548 on chip ATAPI controller.

Won't build, same problem as with AVR32 PATA driver + needs update to
accomodate for libata-link patches.

There are some other problems:

a.

+config PATA_BF54X_DMA
+   bool DMA mode
+   depends on PATA_BF54X
+   default y
+   help
+ Enable DMA mode for Blackfin ATAPI controller.

The preferred solution would be to use module parameter.

If this option is on by default it may be even possible to remove it
completly since this libata update also contains patch from Alan allowing
DMA disable per different classes of ATA devices.

b.

+static struct ata_port_info bfin_port_info[] = {
+   {
+   .sht= bfin_sht,
+   .flags  = ATA_FLAG_SLAVE_POSS
+   | ATA_FLAG_MMIO
+   | ATA_FLAG_NO_LEGACY,
+   .pio_mask   = 0x1f, /* pio0-4 */
+   .mwdma_mask = 0,
+#ifdef CONFIG_PATA_BF54X_DMA
+   .udma_mask  = ATA_UDMA5,
+#else
+   .udma_mask  = 0,
+#endif
+   .port_ops   = bfin_pata_ops,
+   },
+};

MWDMA is never enabled (even if CONFIG_PATA_BF54X_DMA=y) but the driver
contains MWDMA support...

c.

+/**
+ *
+ *Function:   wait_complete
+ *
+ *Description:Waits the interrupt from device
+ *
+ */
+static inline void wait_complete(void __iomem *base, unsigned short mask)
+{
+   unsigned short status;
+   unsigned int i = 0;
+
+#define PATA_BF54X_WAIT_TIMEOUT1
+
+   for (i = 0; i  PATA_BF54X_WAIT_TIMEOUT; i++) {
+   status = ATAPI_GET_INT_STATUS(base)  mask;
+   if (status)
+   break;
+   }
+
+   ATAPI_SET_INT_STATUS(base, mask);
+}

udelay() between retries?

d.

* write_atapi_register()
* read_atapi_register()
* write_atapi_data()
* read_atapi_data()

and

* wait_complete()

need a proper documentation (DocBook-ized etc).

Thanks,
Bart
-
@@ -88,14 +88,15 @@ static int cmd648_cable_detect(struct ata_port *ap)
 
 /**
- * cmd64x_set_piomode  -   set initial PIO mode data
+ * cmd64x_set_piomode  -   set PIO and MWDMA timing
  * @ap: ATA interface
  * @adev: ATA device
@@ -88,14 +88,15 @@ static int cmd648_cable_detect(struct ata_port *ap)
  *
- * Called to do the PIO mode setup.
+ * Called to do the PIO and MWDMA mode setup.
  */
 
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a 

aic build failure in latest linus git tree.

2007-10-12 Thread Dave Jones
  CHK include/linux/utsrelease.h
  CALLscripts/checksyscalls.sh
  CHK include/linux/compile.h
make -C drivers/scsi/aic7xxx/aicasm
*** Install db development libraries
gcc -I/usr/include -I. aicasm.c aicasm_symbol.c aicasm_gram.c 
aicasm_macro_gram.c aicasm_scan.c aicasm_macro_scan.c -o aicasm -ldb
aicasm_symbol.c:48:19: error: aicdb.h: No such file or directory
aicasm_symbol.c:63: error: expected ‘=’, ‘,’, ‘;’, ‘asm’ or ‘__attribute__’ 
before ‘*’ token
aicasm_symbol.c: In function ‘symbol_delete’:
aicasm_symbol.c:86: error: ‘symtable’ undeclared (first use in this function)
aicasm_symbol.c:86: error: (Each undeclared identifier is reported only once
aicasm_symbol.c:86: error: for each function it appears in.)
aicasm_symbol.c:87: error: ‘DBT’ undeclared (first use in this function)
aicasm_symbol.c:87: error: expected ‘;’ before ‘key’
aicasm_symbol.c:89: error: ‘key’ undeclared (first use in this function)
aicasm_symbol.c: In function ‘symtable_open’:
aicasm_symbol.c:133: error: ‘symtable’ undeclared (first use in this function)
aicasm_symbol.c:134: error: ‘DB_HASH’ undeclared (first use in this function)
aicasm_symbol.c: In function ‘symtable_close’:
aicasm_symbol.c:147: error: ‘symtable’ undeclared (first use in this function)
aicasm_symbol.c:148: error: ‘DBT’ undeclared (first use in this function)
aicasm_symbol.c:148: error: expected ‘;’ before ‘key’
aicasm_symbol.c:149: error: expected ‘;’ before ‘data’
aicasm_symbol.c:151: error: ‘key’ undeclared (first use in this function)
aicasm_symbol.c:151: error: ‘data’ undeclared (first use in this function)
aicasm_symbol.c:151: error: ‘R_FIRST’ undeclared (first use in this function)
aicasm_symbol.c: In function ‘symtable_get’:
aicasm_symbol.c:169: error: ‘DBT’ undeclared (first use in this function)
aicasm_symbol.c:169: error: expected ‘;’ before ‘key’
aicasm_symbol.c:170: error: expected ‘;’ before ‘data’
aicasm_symbol.c:173: error: ‘key’ undeclared (first use in this function)
aicasm_symbol.c:176: error: ‘symtable’ undeclared (first use in this function)
aicasm_symbol.c:176: error: ‘data’ undeclared (first use in this function)
aicasm_symbol.c: In function ‘symtable_dump’:
aicasm_symbol.c:472: error: ‘DBT’ undeclared (first use in this function)
aicasm_symbol.c:472: error: expected ‘;’ before ‘key’
aicasm_symbol.c:473: error: expected ‘;’ before ‘data’
aicasm_symbol.c:477: error: ‘symtable’ undeclared (first use in this function)
aicasm_symbol.c:486: error: ‘R_FIRST’ undeclared (first use in this function)
aicasm_symbol.c:487: error: ‘key’ undeclared (first use in this function)
aicasm_symbol.c:487: error: ‘data’ undeclared (first use in this function)
aicasm_symbol.c:524: error: ‘R_NEXT’ undeclared (first use in this function)
make[4]: *** [aicasm] Error 1
make[3]: *** [drivers/scsi/aic7xxx/aicasm/aicasm] Error 2
make[2]: *** [drivers/scsi/aic7xxx] Error 2
make[1]: *** [drivers/scsi] Error 2
make: *** [drivers] Error 2


-- 
http://www.codemonkey.org.uk
-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Problem with SCSI RAID

2007-10-12 Thread Delca
My server recently sent two emails with the following body:

email 1:Adapter 0 Channel 0 Target 0: Media Error Count=4,
Other Error Count=0
email 2:Adapter 0 Channel 0 Target 1: Media Error Count=0,
Other Error Count=1

My question is... What Media Error Count and Other Error Count means?
that means I should change disks?

I've a Dell machine with a Perc 4e/Si RAID controller. And using
Megamon and dellmgr to check RAID status.


Thanks!

-- 
Santiago del Castillo
-
To unsubscribe from this list: send the line unsubscribe linux-scsi in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html